@@ -1,5 +1,5 @@
 // main31.cc is a part of the PYTHIA event generator.
-// Copyright (C) 2012 Richard Corke, Torbjorn Sjostrand.
+// Copyright (C) 2013 Richard Corke, Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -260,7 +260,7 @@ public:
   // Extraction of pThard based on the incoming event.
   // Assume that all the final-state particles are in a continuous block
   // at the end of the event and the final entry is the POWHEG emission.
-  // If there is no POWHEG emission, then pThard is set to Qfac.
+  // If there is no POWHEG emission, then pThard is set to SCALUP.
 
   bool canVetoMPIStep()    { return true; }
   int  numberVetoMPIStep() { return 1; }
@@ -289,9 +289,9 @@ public:
     bool isEmt = (count == nFinal) ? false : true;
     int  iEmt  = (isEmt) ? e.size() - 1 : -1;
 
-    // If there is no radiation or if pThardMode is 0 then set pThard to Qfac.
+    // If there is no radiation or if pThardMode is 0 then set pThard to SCALUP.
     if (!isEmt || pThardMode == 0) {
-      pThard = infoPtr->QFac();
+      pThard = infoPtr->scalup();
       
     // If pThardMode is 1 then the pT of the POWHEG emission is checked against
     // all other incoming and outgoing partons, with the minimal value taken
@@ -303,7 +303,6 @@ public:
     // taken
     } else if (pThardMode == 2) {
       pThard = pTcalc(e, -1, -1, -1, -1, -1);
-
     }
 
     // Find MPI veto pT if necessary
@@ -312,7 +311,7 @@ public:
     }
 
 #ifdef DBGOUTPUT
-    cout << "doVetoMPIStep: Qfac = " << infoPtr->QFac()
+    cout << "doVetoMPIStep: Qfac = " << infoPtr->scalup()
          << ", pThard = " << pThard << endl << endl;
 #endif
 
@@ -411,7 +410,7 @@ public:
     int r   = (pTemtMode == 0) ? iRecAft : -1;
 
     // When pTemtMode is 0 or 1, iEmt has been selected
-    double pTemt;
+    double pTemt = 0.;
     if (pTemtMode == 0 || pTemtMode == 1) {
       // Which parton is emitted, based on emittedMode:
       //  0 - Pythia definition of emitted
@@ -594,6 +593,7 @@ int main(int, char **) {
   cout << endl;
 
   // Done.                           
+  if (powhegHooks) delete powhegHooks;
   return 0;
 }
 
