@@ -1,5 +1,5 @@
 // History.h is a part of the PYTHIA event generator.
-// Copyright (C) 2012 Torbjorn Sjostrand.
+// Copyright (C) 2013 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -122,6 +122,8 @@ public:
            Info* infoPtrIn,
            bool isOrdered,
            bool isStronglyOrdered,
+           bool isAllowed,
+           bool isNextInInput,
            double probin,
            History * mothin);
 
@@ -130,6 +132,10 @@ public:
     for ( int i = 0, N = children.size(); i < N; ++i ) delete children[i];
   }
 
+  // Function to project paths onto desired paths.
+  bool projectOntoDesiredHistories();
+
+  // For CKKW-L, NL3 and UMEPS:
   // In the initial history node, select one of the paths according to
   // the probabilities. This function should be called for the initial
   // history node.
@@ -142,8 +148,50 @@ public:
   double weightTREE(PartonLevel* trial, AlphaStrong * asFSR,
                     AlphaStrong * asISR, double RN);
 
+  // For default NL3:
+  // Return weight of virtual correction and subtractive for NL3 merging
+  double weightLOOP(PartonLevel* trial, double RN);
+  // Return O(\alpha_s)-term of CKKWL-weight for NL3 merging
+  double weightFIRST(PartonLevel* trial, AlphaStrong* asFSR,
+                  AlphaStrong* asISR, double RN, Rndm* rndmPtr );
+
+  // For UMEPS:
+  double weight_UMEPS_TREE(PartonLevel* trial, AlphaStrong * asFSR,
+                    AlphaStrong * asISR, double RN);
+  double weight_UMEPS_SUBT(PartonLevel* trial, AlphaStrong * asFSR,
+                    AlphaStrong * asISR, double RN);
+
+  // For unitary NL3:
+  double weight_UNLOPS_TREE(PartonLevel* trial, AlphaStrong * asFSR,
+                    AlphaStrong * asISR, double RN);
+  double weight_UNLOPS_SUBT(PartonLevel* trial, AlphaStrong * asFSR,
+                    AlphaStrong * asISR, double RN);
+  double weight_UNLOPS_LOOP(PartonLevel* trial, double RN);
+  double weight_UNLOPS_SUBTNLO(PartonLevel* trial, double RN);
+  double weight_UNLOPS_CORRECTION( int order, PartonLevel* trial,
+                  AlphaStrong* asFSR, AlphaStrong* asISR, 
+                  double RN, Rndm* rndmPtr );
+
+  // Function to check if any allowed histories were found
+  bool foundAllowedHistories() {
+    return (children.size() > 0 && foundAllowedPath); }
+  // Function to check if any ordered histories were found
+  bool foundOrderedHistories() {
+    return (children.size() > 0 && foundOrderedPath); }
+  // Function to check if any ordered histories were found
+  bool foundCompleteHistories() {
+    return (children.size() > 0 && foundCompletePath); }
+
   // Function to set the state with complete scales for evolution 
   void getStartingConditions( const double RN, Event& outState );
+  // Function to get the state with complete scales for evolution 
+  bool getClusteredEvent( const double RN, int nSteps, Event& outState);
+  // Function to get the first reclustered state above the merging scale. 
+  bool getFirstClusteredEventAboveTMS( const double RN, int nDesired,
+    Event& process, int & nPerformed, bool updateProcess = true );
+  // Function to return the depth of the history (i.e. the number of
+  // reclustered splittings)
+  int nClusterings();
 
   // Function to get the lowest multiplicity reclustered event
   Event lowestMultProc( const double RN) {
@@ -152,12 +200,21 @@ public:
   }
 
   // Calculate and return pdf ratio
-  double getPDFratio( int side, bool forSudakov,
+  double getPDFratio( int side, bool forSudakov, bool useHardPDF,
                       int flavNum, double xNum, double muNum,
                       int flavDen, double xDen, double muDen);
 
+  // Make Pythia class friend
+  friend class Pythia;
+  // Make Merging class friend
+  friend class Merging;
+
 private:
 
+  // Number of trial emission to use for calculating the average number of 
+  // emissions
+  static const int NTRIAL;
+
   // Function to set all scales in the sequence of states. This is a
   // wrapper routine for setScales and setEventScales methods
   void setScalesInHistory();
@@ -200,19 +257,37 @@ private:
   //                       unchanged copies of iPart in subsequent steps
   void scaleCopies(int iPart, const Event& refEvent, double rho);
 
-  // Functions to set the OVERALL EVENT SCALES [=state.scale()] to
+  // Function to set the OVERALL EVENT SCALES [=state.scale()] to
   // the scale of the last clustering
   // NO INPUT
   // NO OUTPUT
   void setEventScales();
 
-  void printScales() {
-    if( mother ) mother->printScales();
-    cout << " scale " << scale
-         << " clusterIn " << clusterIn.pT()
-         << " state.scale() " << state.scale()
-         << endl;
-  }
+  // Function to print information on the reconstructed scales in one path.
+  // For debug only.
+  void printScales() { if ( mother ) mother->printScales();
+    cout << " size " << state.size() << " scale " << scale << " clusterIn "
+      << clusterIn.pT() << " state.scale() " << state.scale() << endl; }
+
+  // Function to project paths onto desired paths.
+  bool trimHistories();
+  // Function to tag history for removal.
+  void remove(){ doInclude = false; }
+  // Function to return flag of allowed histories to choose from.
+  bool keep(){ return doInclude; }
+  // Function implementing checks on a paths, for deciding if the path should
+  // be considered valid or not.
+  bool keepHistory();
+  // Function to check if a path is ordered in evolution pT.
+  bool isOrderedPath( double maxscale );
+
+  bool followsInputPath();
+
+  // Function to check if all reconstucted states in a path pass the merging
+  // scale cut.
+  bool allIntermediateAboveRhoMS( double rhoms, bool good = true );
+  // Function to check if any ordered paths were found (and kept).
+  bool foundAnyOrderedPaths();
 
   // Functions to return the z value of the last ISR splitting
   // NO INPUT
@@ -234,6 +309,12 @@ private:
   // OUTPUT double : pT scale of last FSR splitting in history 
   double pTFSR();
 
+  // Functions to return the event with nSteps additional partons
+  // INPUT  int   : Number of splittings in the event,
+  //                as counted from core 2->2 process
+  // OUTPUT Event : event with nSteps additional partons 
+  Event clusteredState( int nSteps);
+
   // Function to choose a path from all paths in the tree
   // according to their splitting probabilities
   // IN double    : Random number
@@ -248,14 +329,44 @@ private:
   //                  trial shower
   //     double     : alpha_s value used in ME calculation
   //     double     : Maximal mass scale of the problem (e.g. E_CM)
-  //     AlphaStrong: Initialised shower alpha_s object for FSR alpha_s 
+  //     AlphaStrong: Initialised shower alpha_s object for FSR alpha_s
   //                  ratio calculation
-  //     AlphaStrong: Initialised shower alpha_s object for ISR alpha_s 
+  //     AlphaStrong: Initialised shower alpha_s object for ISR alpha_s
   //                  ratio calculation (can be different from previous)
   double weightTree(PartonLevel* trial, double as0, double maxscale,
-    AlphaStrong * asFSR, AlphaStrong * asISR, double& asWeight,
-    double& pdfWeight);
+    double pdfScale, AlphaStrong * asFSR, AlphaStrong * asISR,
+    double& asWeight, double& pdfWeight);
 
+  // Function to return the \alpha_s-ratio part of the CKKWL weight.
+  double weightTreeALPHAS( double as0, AlphaStrong * asFSR, 
+    AlphaStrong * asISR );
+  // Function to return the PDF-ratio part of the CKKWL weight.
+  double weightTreePDFs( double maxscale, double pdfScale );
+  // Function to return the no-emission probability part of the CKKWL weight.
+  double weightTreeEmissions( PartonLevel* trial, int type, int njetMax, 
+    double maxscale );
+
+  // Function to generate the O(\alpha_s)-term of the CKKWL-weight
+  double weightFirst(PartonLevel* trial, double as0, double muR,
+    double maxscale, AlphaStrong * asFSR, AlphaStrong * asISR, Rndm* rndmPtr );
+
+  // Function to generate the O(\alpha_s)-term of the \alpha_s-ratios
+  // appearing in the CKKWL-weight.
+  double weightFirstALPHAS( double as0, double muR, AlphaStrong * asFSR,
+    AlphaStrong * asISR);
+  // Function to generate the O(\alpha_s)-term of the PDF-ratios
+  // appearing in the CKKWL-weight.
+  double weightFirstPDFs( double as0, double maxscale, double pdfScale,
+    Rndm* rndmPtr );
+  // Function to generate the O(\alpha_s)-term of the no-emission
+  // probabilities appearing in the CKKWL-weight.
+  double weightFirstEmissions(PartonLevel* trial, double as0, double maxscale,
+    AlphaStrong * asFSR, AlphaStrong * asISR, bool fixpdf, bool fixas );
+
+  // Function to return the default factorisation scale of the hard process.
+  double hardFacScale(const Event& event);
+  // Function to return the default renormalisation scale of the hard process.
+  double hardRenScale(const Event& event);
 
   // Perform a trial shower using the \a pythia object between
   // maxscale down to this scale and return the corresponding Sudakov
@@ -265,10 +376,24 @@ private:
   // OUT  0.0       : trial shower emission outside allowed pT range
   //      1.0       : trial shower successful (any emission was below
   //                  the minimal scale )
-  double doTrialShower(PartonLevel* trial, double maxscale);
+  double doTrialShower(PartonLevel* trial, int type, double maxscale, 
+    double minscale = 0.);
 
-  // Check if a ordered (and complete) path has been found in the
-  // initial node, in which case we will no longer be interested in
+  // Function to bookkeep the indices of weights generated in countEmissions
+  bool updateind(vector<int> & ind, int i, int N);
+
+  // Function to count number of emissions between two scales for NLO merging
+  vector<double> countEmissions(PartonLevel* trial, double maxscale,
+    double minscale, int showerType, double as0, AlphaStrong * asFSR,
+    AlphaStrong * asISR, int N, bool fixpdf, bool fixas);
+
+  // Function to integrate PDF ratios between two scales over x and t,
+  // where the PDFs are always evaluated at the lower t-integration limit
+  double monteCarloPDFratios(int flav, double x, double maxScale,
+           double minScale, double pdfScale, double asME, Rndm* rndmPtr);
+
+  // Default: Check if a ordered (and complete) path has been found in
+  // the initial node, in which case we will no longer be interested in
   // any unordered paths.
   bool onlyOrderedPaths();
 
@@ -277,6 +402,11 @@ private:
   // any unordered paths.
   bool onlyStronglyOrderedPaths();
 
+  // Check if an allowed (according to user-criterion) path has been found in 
+  // the initial node, in which case we will no longer be interested in
+  // any forbidden paths.
+  bool onlyAllowedPaths();
+
   // When a full path has been found, register it with the initial
   // history node.
   // IN  History : History to be registered as path
@@ -284,18 +414,18 @@ private:
   //     bool    : Specifying if path is complete down to 2->2 process
   // OUT true if History object forms a plausible path (eg prob>0 ...)
   bool registerPath(History & l, bool isOrdered, bool isStronglyOrdered,
-         bool isComplete);
+         bool isAllowed, bool isComplete);
 
   // For the history-defining state (and if necessary interfering
   // states), find all possible clusterings.
   // NO INPUT
   // OUT vector of all (rad,rec,emt) systems
-  vector<Clustering> getAllClusterings();
+  vector<Clustering> getAllQCDClusterings();
 
   // For one given state, find all possible clusterings.
   // IN  Event : state to be investigated
   // OUT vector of all (rad,rec,emt) systems in the state
-  vector<Clustering> getClusterings( const Event& event);
+  vector<Clustering> getQCDClusterings( const Event& event);
 
   // Function to construct (rad,rec,emt) triples from the event
   // IN  int   : Position of Emitted in event record for which
@@ -306,10 +436,20 @@ private:
   //              causing a 2 -> 3 dipole splitting
   //     Event : event record to be checked for ptential partners
   // OUT vector of all allowed radiator+recoiler+emitted triples
-  vector<Clustering> findTriple (int EmtTagIn, int colTopIn, 
-                        const Event& event,
-                        vector<int> PosFinalPartn,
-                        vector <int> PosInitPartn );
+  vector<Clustering> findQCDTriple (int EmtTagIn, int colTopIn, 
+                       const Event& event, vector<int> PosFinalPartn,
+                       vector <int> PosInitPartn );
+
+  vector<Clustering> getAllEWClusterings();
+  vector<Clustering> getEWClusterings( const Event& event);
+  vector<Clustering> findEWTriple( int EmtTagIn, const Event& event,
+                       vector<int> PosFinalPartn );
+
+  vector<Clustering> getAllSQCDClusterings();
+  vector<Clustering> getSQCDClusterings( const Event& event);
+  vector<Clustering> findSQCDTriple (int EmtTagIn, int colTopIn, 
+                       const Event& event, vector<int> PosFinalPartn,
+                       vector <int> PosInitPartn );
 
   // Calculate and return the probability of a clustering.
   // IN  Clustering : rad,rec,emt - System for which the splitting
@@ -329,9 +469,13 @@ private:
   void setupBeams();
 
   // Calculate the PDF ratio used in the argument of the no-emission
-  // probability
+  // probability.
   double pdfForSudakov();
 
+  // Calculate the hard process matrix element to include in the selection
+  // probability.
+  double hardProcessME( const Event& event);
+
   // Perform the clustering of the current state and return the
   // clustered state.
   // IN Clustering : rad,rec,emt triple to be clustered to two partons
@@ -460,7 +604,8 @@ private:
   //     Event    : Event to be searched in
   // OUT int      : > 0 : Position of matching particle in event
   //                < 0 : No match in event
-  int FindParticle(const Particle& particle, const Event& event);
+  int FindParticle( const Particle& particle, const Event& event,
+    bool checkStatus = true );
 
   // Function to check if rad,emt,rec triple is allowed for clustering
   // IN int rad,emt,rec,partner : Positions (in event record) of the three
@@ -505,10 +650,28 @@ private:
   double getCurrentZ(const int rad, const int rec, const int emt) const;
 
   // Function to compute "pythia pT separation" from Particle input
-  double pTLund(const Particle& RadAfterBranch, const Particle& EmtAfterBranch,
+  double pTLund(const Particle& RadAfterBranch,const Particle& EmtAfterBranch,
                 const Particle& RecAfterBranch, int ShowerType);
 
-private:
+  // Function to return the position of the initial line before (or after)
+  // a single (!) splitting.
+  int posChangedIncoming(const Event& event, bool before);
+
+  // Function to give back the ratio of PDFs and PDF * splitting kernels
+  // needed to convert a splitting at scale pdfScale, chosen with running
+  // PDFs, to a splitting chosen with PDFs at a fixed scale mu. As needed to
+  // properly count emissions.
+  double pdfFactor( const Event& event, const int type, double pdfScale,
+    double mu );
+
+  // Function giving the product of splitting kernels and PDFs so that the
+  // resulting flavour is given by flav. This is used as a helper routine 
+  // to dgauss
+  double integrand(int flav, double x, double scaleInt, double z);
+
+  //----------------------------------------------------------------------//
+  // Class members.
+  //----------------------------------------------------------------------//
 
   // The state of the event correponding to this step in the
   // reconstruction.
@@ -532,6 +695,14 @@ private:
   // unless this is the initial step (mother == 0).
   double sumpath;
 
+  // The different allowed paths after projection, indexed with
+  // the (incremental) corresponding probability. This map is empty
+  // unless this is the initial step (mother == 0).
+  map<double,History *> goodBranches, badBranches;
+  // The sum of the probabilities of allowed paths after projection. This is
+  // zero unless this is the initial step (mother == 0).
+  double sumGoodBranches, sumBadBranches;
+
   // This is set true if an ordered (and complete) path has been found
   // and inserted in paths.
   bool foundOrderedPath;
@@ -540,6 +711,10 @@ private:
   // and inserted in paths.
   bool foundStronglyOrderedPath;
 
+  // This is set true if an allowed (according to a user criterion) path has 
+  // been found and inserted in paths.
+  bool foundAllowedPath;
+
   // This is set true if a complete (with the required number of
   // clusterings) path has been found and inserted in paths.
   bool foundCompletePath;
@@ -549,13 +724,22 @@ private:
   // mother == 0).
   double scale;
 
+  // Flag indicating if a clustering in the construction of all histories is
+  // the next clustering demanded by inout clusterings in LesHouches 2.0
+  // accord.
+  bool nextInInput;
+
   // The probability associated with this step and the previous steps.
   double prob;
 
-  // The partons and scale of the last clustering
+  // The partons and scale of the last clustering.
   Clustering clusterIn;
+  int iReclusteredOld, iReclusteredNew;
 
-  // Pointer to MergingHooks object to get all the settings
+  // Flag to include the path amongst allowed paths.
+  bool doInclude;
+
+  // Pointer to MergingHooks object to get all the settings.
   MergingHooks* mergingHooksPtr;
 
    // The default constructor is private.
