@@ -1,5 +1,5 @@
 // PhaseSpace.h is a part of the PYTHIA event generator.
-// Copyright (C) 2012 Torbjorn Sjostrand.
+// Copyright (C) 2013 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -155,7 +155,7 @@ protected:
          increaseMaximum;
   int    gmZmodeGlobal;
   double mHatGlobalMin, mHatGlobalMax, pTHatGlobalMin, pTHatGlobalMax, 
-         pTHatMinDiverge, minWidthBreitWigners;
+         pTHatMinDiverge, minWidthBreitWigners, mRecalculate;
  
   // Information on incoming beams.
   int    idA, idB;
@@ -163,9 +163,10 @@ protected:
   bool   hasLeptonBeams, hasPointLeptons;
 
  // Cross section information.
-  bool   newSigmaMx, canModifySigma, canBiasSelection;
+  bool   newSigmaMx, canModifySigma, canBiasSelection, canBias2Sel;
   int    gmZmode;
-  double wtBW, sigmaNw, sigmaMx, sigmaPos, sigmaNeg, biasWt;
+  double bias2SelPow, bias2SelRef, wtBW, sigmaNw, sigmaMx, sigmaPos, 
+         sigmaNeg, biasWt;
 
   // Process-specific kinematics properties, almost always available.
   double mHatMin, mHatMax, sHatMin, sHatMax, pTHatMin, pTHatMax, 
@@ -241,6 +242,12 @@ protected:
   void   trialMass(int iM);
   double weightMass(int iM);
 
+  // The error function erf(x) should normally be in your math library,
+  // but if not uncomment this simple parametrization by Sergei Winitzki.
+  //double erf(double x) { double x2 = x * x; double kx2 = 0.147 * x2; 
+  //  double tmp = sqrt(1. - exp(-x2 * (4./M_PI + kx2) / (1. + kx2)));
+  //  return ((x >= 0.) ? tmp : -tmp); } 
+
 };
  
 //==========================================================================
@@ -368,7 +375,7 @@ private:
 
   // Constants: could only be changed in the code itself.
   static const int    NTRY;
-  static const double EXPMAX, DIFFMASSMAX;
+  static const double EXPMAX, DIFFMASSMARGIN;
 
   // Initialization data, in constructor or read from Settings.
   bool   isDiffA, isDiffB;
@@ -409,18 +416,18 @@ public:
  private:
   
   // Constants: could only be changed in the code itself.
-  static const int  NTRY;
-  static const int  NINTEG2;
+  static const int    NTRY, NINTEG2;
+  static const double EXPMAX, DIFFMASSMIN, DIFFMASSMARGIN;
     
   // Local variables to calculate DPE kinematics.
   int    PomFlux;
-  double dpepmax, dymin0,dymax, s1, s2, lambda12S, t1, pt1, pz1, phi1,
-         t2, pt2, pz2, phi2;
+  double epsilonPF, alphaPrimePF, s1, s2, m5min, s5min, tLow[2], tUpp[2], 
+         bMin[2], tAux[2], bSlope1, bSlope2, probSlope1[2], tAux1[2], 
+         tAux2[2], bSlope, xIntPF, xIntInvPF, xtCorPF, mp24DL, coefDL, 
+         epsMBR, alphMBR, m2minMBR, dyminMBR, dyminSigMBR, dyminInvMBR, 
+         dpepmax, t1, t2;
   Vec4   p1, p2, p3, p4, p5;
 
-  // Parameters for MBR model.
-  double eps, alph, m2min, dyminCD, dyminSigCD;
-
 };
  
 //==========================================================================
