@@ -1,5 +1,5 @@
 // SigmaProcess.h is a part of the PYTHIA event generator.
-// Copyright (C) 2012 Torbjorn Sjostrand.
+// Copyright (C) 2013 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -37,6 +37,7 @@
 #include "Settings.h"
 #include "SigmaTotal.h"
 #include "StandardModel.h"
+#include "SLHAinterface.h"
 #include "SusyLesHouches.h"
 
 namespace Pythia8 {
@@ -90,8 +91,8 @@ public:
   // Perform simple initialization and store pointers.
   void init(Info* infoPtrIn, Settings* settingsPtrIn,
     ParticleData* particleDataPtrIn, Rndm* rndmPtrIn,
-    BeamParticle* beamAPtrIn, BeamParticle* beamBPtrIn, Couplings* couplings, 
-	    SigmaTotal* sigmaTotPtrIn = 0, SusyLesHouches* slhaPtr = 0); 
+    BeamParticle* beamAPtrIn, BeamParticle* beamBPtrIn, Couplings* couplings,
+    SigmaTotal* sigmaTotPtrIn = 0, SLHAinterface* slhaInterfacePtrIn = 0); 
 
   // Store or replace Les Houches pointer.
   void setLHAPtr( LHAup* lhaUpPtrIn) {lhaUpPtr = lhaUpPtrIn;}  
@@ -267,7 +268,9 @@ public:
 protected:
 
   // Constructor.
-  SigmaProcess() {for (int i = 0; i < 6; ++i) mSave[i] = 0.;}
+  SigmaProcess() : infoPtr(0), settingsPtr(0), particleDataPtr(0),
+    rndmPtr(0), beamAPtr(0), beamBPtr(0), couplingsPtr(0), sigmaTotPtr(0),
+    slhaPtr(0), lhaUpPtr(0) {for (int i = 0; i < 6; ++i) mSave[i] = 0.;}
 
   // Constants: could only be changed in the code itself.
   static const double CONVERT2MB, MASSMARGIN, COMPRELERR;
@@ -295,7 +298,7 @@ protected:
   // Pointer to the total/elastic/diffractive cross section object.
   SigmaTotal*     sigmaTotPtr;
 
-  // Pointer to the SLHA object.
+  // Pointer to an SLHA object.
   SusyLesHouches* slhaPtr;
 
   // Pointer to LHAup for generating external events.
@@ -506,7 +509,8 @@ public:
 protected:
 
   // Constructor.
-  Sigma2Process() {}
+  Sigma2Process() : tH(0.), uH(0.), tH2(0.), uH2(0.), m3(0.), s3(0.), 
+    m4(0.), s4(0.), pT2(0.), runBW3(0.), runBW4(0.) {}
 
   // Store kinematics and set scales for resolved 2 -> 2 process.
   virtual void   store2Kin( double x1in, double x2in, double sHin, 
