@@ -102,7 +102,7 @@ cross section bigger than the nondiffractive one by reducing
 <p/><strong>string Info::name() &nbsp;</strong> <br/>
   
 <strong>int Info::code() &nbsp;</strong> <br/>
-the name and code of the process that occured.
+the name and code of the process that occurred.
   
 
 <a name="method9"></a>
@@ -159,7 +159,7 @@ the hardest collision to be identified.
   
 <strong>int Info::nFinalSub() &nbsp;</strong> <br/>
 the name, code and number of final-state partons in the subprocess
-that occured when <code>hasSub()</code> is true. For a minimum-bias event 
+that occurred when <code>hasSub()</code> is true. For a minimum-bias event 
 the <code>code</code> would always be 101, while <code>codeSub()</code> 
 would vary depending on the actual hardest interaction, e.g. 111 for 
 <i>g g -> g g</i>. For a Les Houches event the <code>code</code> would 
@@ -171,7 +171,7 @@ information for such particular subcollisions.
 <h3>Hard process initiators</h3>
 
 The methods in this sections refer to the two initial partons of the
-hard <i>2 -> n</i> process.
+hard <i>2 -> n</i> process (diffraction excluded; see below).
 
 <a name="method18"></a>
 <p/><strong>int Info::id1() &nbsp;</strong> <br/>
@@ -209,7 +209,10 @@ Information is not set if you switch off parton-level processing.
 
 The methods in this section refer to the partons for which parton 
 densities have been defined, in order to calculate the cross section
-of the hard process. These partons would normally agree with the 
+of the hard process (diffraction excluded; see below). 
+
+<p/>
+These partons would normally agree with the 
 ones above, the initiators of the <i>2 -> n</i> process, but it 
 does not have to be so. Currently the one counterexample is POWHEG 
 events [<a href="Bibliography.php" target="page">Ali10</a>]. Here the original hard process could be
@@ -284,16 +287,32 @@ the <i>Q</i> or <i>Q^2</i> renormalization scale at which
 <i>alpha_strong</i> and <i>alpha_electromagnetic</i> were evaluated.
   
 
+<a name="method28"></a>
+<p/><strong>double Info::scalup() &nbsp;</strong> <br/>
+returns the stored <code>SCALUP</code> value for Les Houches events, 
+and else zero. It may agree with both the <code>QFac()</code> and 
+<code>QRen()</code> values, as explained above. However, to repeat,
+should the input <code>SCALUP</code> scale be negative, separate positive 
+factorization and renormalization scales are calculated and set as for 
+internally generated events. Furthermore, when PDF info is supplied for 
+the Les Houches event, the factorization scale is set by this PDF info 
+(<code>scalePDF</code>), which can disagree with <code>SCALUP</code>. 
+  
+
 <h3>Hard process kinematics</h3>
 
-<a name="method28"></a>
+The methods in this section provide info on the kinematics of the hard 
+processes, with special emphasis on <i>2 -> 2</i> (diffraction excluded; 
+see below). 
+
+<a name="method29"></a>
 <p/><strong>double Info::mHat() &nbsp;</strong> <br/>
   
 <strong>double Info::sHat() &nbsp;</strong> <br/>
 the invariant mass and its square for the hard process.
   
 
-<a name="method29"></a>
+<a name="method30"></a>
 <p/><strong>double Info::tHat() &nbsp;</strong> <br/>
   
 <strong>double Info::uHat() &nbsp;</strong> <br/>
@@ -301,7 +320,7 @@ the remaining two Mandelstam variables; only defined for <i>2 -> 2</i>
 processes. 
   
 
-<a name="method30"></a>
+<a name="method31"></a>
 <p/><strong>double Info::pTHat() &nbsp;</strong> <br/>
   
 <strong>double Info::pT2Hat() &nbsp;</strong> <br/>
@@ -309,14 +328,14 @@ transverse momentum and its square in the rest frame of a <i>2 -> 2</i>
 processes. 
   
 
-<a name="method31"></a>
+<a name="method32"></a>
 <p/><strong>double Info::m3Hat() &nbsp;</strong> <br/>
   
 <strong>double Info::m4Hat() &nbsp;</strong> <br/>
 the masses of the two outgoing particles in a <i>2 -> 2</i> processes. 
   
 
-<a name="method32"></a>
+<a name="method33"></a>
 <p/><strong>double Info::thetaHat() &nbsp;</strong> <br/>
   
 <strong>double Info::phiHat() &nbsp;</strong> <br/>
@@ -324,9 +343,57 @@ the polar and azimuthal scattering angles in the rest frame of
 a <i>2 -> 2</i> process.
   
 
+<h3>Diffraction</h3>
+
+Information on the primary elastic or 
+<?php $filepath = $_GET["filepath"];
+echo "<a href='Diffraction.php?filepath=".$filepath."' target='page'>";?>diffractive</a> process
+(<i>A B -> A B, X1 B, A X2, X1 X2, A X B</i>) can be obtained with 
+the methods in the "Hard process kinematics" section above. The 
+variables here obviously are <i>s, t, u, ...</i> rather than 
+<i>sHat, tHat, uHat, ...</i>, but the method names remain to avoid 
+unnecessary duplication. Most other methods are irrelevant for a 
+primary elastic/diffractive process.
+
+<p/>Central diffraction <i>A B -> A X B</i> is a <i>2 -> 3</i>
+process, and therefore most of the <i>2 -> 2</i> variables are 
+no longer relevant. The <code>tHat()</code> and <code>uHat()</code> 
+methods instead return the two <i>t</i> values at the <i>A -> A</i> 
+and <i>B -> B</i> vertices, and <code>pTHat()</code> the average 
+transverse momentum of the three outgoing "particles", while 
+<code>thetaHat()</code> and <code>phiHat()</code> are undefined.
+
+<p/>
+While the primary interaction does not contain a hard process,
+the diffractive subsystems can contain them, but need not. 
+Specifically, double diffraction can contain two separate hard 
+subprocesses, which breaks the methods above. Most of them have been 
+expanded with an optional argument to address properties of diffractive 
+subsystems. This argument can take four values:
+<ul>
+<li>0 : default argument, used for normal nondiffractive events or 
+the primary elastic/diffractive process (see above);
+<li>1 : the <i>X1</i> system in single diffraction <i>A B -> X1 B</i>
+or double diffraction <i>A B -> X1 X2</i>;
+<li>2 : the <i>X2</i> system in single diffraction <i>A B -> A X2</i>
+or double diffraction <i>A B -> X1 X2</i>;
+<li>3 : the <i>X</i> system in central diffraction <i>A B -> A X B</i>.
+</ul>
+The argument is defined for all of the methods in the three sections above,
+"Hard process initiators", "Hard process parton densities and scales" and
+"Hard process kinematics", with the exception of the <code>isValence</code>
+methods. Also the four final methods of "The event type" section, the 
+<code>...Sub()</code> methods, take this argument. But recall that they
+will only provide meaningful answers, firstly if there is a system of the 
+requested type, and secondly if there is a hard subprocess in this system. 
+A simple check for this is that <code>id1()</code> has to be nonvanishing. 
+The methods below this section do not currently provide information 
+specific to diffractive subsystems, e.g. the MPI information is not 
+bookkept in such cases.    
+
 <h3>Event weight and activity</h3>
 
-<a name="method33"></a>
+<a name="method34"></a>
 <p/><strong>double Info::weight() &nbsp;</strong> <br/>
 weight assigned to the current event. Is normally 1 and thus 
 uninteresting. However, there are several cases where one may have
@@ -351,7 +418,7 @@ come with a weight. Specifically, for strategies <i>+4</i> and
 but converted at output.) 
   
 
-<a name="method34"></a>
+<a name="method35"></a>
 <p/><strong>double Info::weightSum() &nbsp;</strong> <br/>
 Sum of weights accumulated during the run. For unweighted events this
 agrees with the number of generated events. In order to obtain 
@@ -361,7 +428,7 @@ divided by the bin width.) Normalization to cross section also
 required multiplication by <code>sigmaGen()</code> below.
   
 
-<a name="method35"></a>
+<a name="method36"></a>
 <p/><strong>int Info::lhaStrategy() &nbsp;</strong> <br/>
 normally 0, but if Les Houches events are input then it gives the 
 event weighting strategy, see 
@@ -369,18 +436,18 @@ event weighting strategy, see
 echo "<a href='LesHouchesAccord.php?filepath=".$filepath."' target='page'>";?>Les Houches Accord</a>.
   
 
-<a name="method36"></a>
+<a name="method37"></a>
 <p/><strong>int Info::nISR() &nbsp;</strong> <br/>
   
 <strong>int Info::nFSRinProc() &nbsp;</strong> <br/>
   
 <strong>int Info::nFSRinRes() &nbsp;</strong> <br/>
 the number of emissions in the initial-state showering, in the final-state
-showering excluding resonance decys, and in the final-state showering
+showering excluding resonance decays, and in the final-state showering
 inside resonance decays, respectively.
   
 
-<a name="method37"></a>
+<a name="method38"></a>
 <p/><strong>double Info::pTmaxMPI() &nbsp;</strong> <br/>
   
 <strong>double Info::pTmaxISR() &nbsp;</strong> <br/>
@@ -391,7 +458,7 @@ process type and scale choice for the hard interactions. The actual
 evolution will run down from these scales.
   
 
-<a name="method38"></a>
+<a name="method39"></a>
 <p/><strong>double Info::pTnow() &nbsp;</strong> <br/>
 The current <i>pT</i> scale in the combined MPI, ISR and FSR evolution.
 Useful for classification in <?php $filepath = $_GET["filepath"];
@@ -399,23 +466,38 @@ echo "<a href='UserHooks.php?filepath=".$filepath."' target='page'>";?>user hook
 but not once the event has been evolved.  
   
 
-<a name="method39"></a>
+<a name="method40"></a>
 <p/><strong>double Info::mergingWeight() &nbsp;</strong> <br/>
-combined CKKW-L weight assigned to the current event. If CKKW-L merging is 
+combined leading-order merging weight assigned to the current event, if 
+tree-level multi-jet merging (i.e. 
+<a href="CKKWLMerging.html" target="page"> CKKW-L</a> or
+<a href="UMEPSMerging.html" target="page"> UMEPS</a> merging) is attempted. If 
+tree-level multi-jet merging is 
 performed, all histograms should be filled with this weight, as discussed in 
- <a href="MatrixElementMerging.html" target="page"> Matrix Element
-Merging</a>.
+ <a href="CKKWLMerging.html" target="page"> CKKW-L Merging</a> and 
+ <a href="UMEPSMerging.html" target="page"> UMEPS Merging</a>.
+  
+
+<a name="method41"></a>
+<p/><strong>double Info::mergingWeightNLO() &nbsp;</strong> <br/>
+combined NLO merging weight assigned to the current event, if 
+NLO multi-jet merging (i.e. 
+<a href="NLOMerging.html" target="page"> NL<sup>3</sup></a> or
+<a href="NLOMerging.html" target="page"> UNLOPS</a> merging) is attempted. If 
+NLO multi-jet merging is 
+performed, all histograms should be filled with this weight, as discussed in 
+ <a href="NLOMerging.html" target="page"> NLO Merging</a> .
   
 
 <h3>Multiparton interactions</h3>
 
-<a name="method40"></a>
+<a name="method42"></a>
 <p/><strong>double Info::a0MPI() &nbsp;</strong> <br/>
 The value of a0 when an x-dependent matter profile is used,
 <code>MultipartonInteractions:bProfile = 4</code>.
   
 
-<a name="method41"></a>
+<a name="method43"></a>
 <p/><strong>double Info::bMPI() &nbsp;</strong> <br/>
 The impact parameter <i>b</i> assumed for the current collision when
 multiparton interactions are simulated. Is not expressed in any physical
@@ -424,7 +506,7 @@ for minimum-bias events (meaning less than that for events with hard
 processes). 
   
 
-<a name="method42"></a>
+<a name="method44"></a>
 <p/><strong>double Info::enhanceMPI() &nbsp;</strong> <br/>
 The choice of impact parameter implies an enhancement or depletion of
 the rate of subsequent interactions, as given by this number. Again
@@ -432,14 +514,14 @@ the average is normalized be unity for minimum-bias events (meaning
 more than that for events with hard processes).  
   
 
-<a name="method43"></a>
+<a name="method45"></a>
 <p/><strong>int Info::nMPI() &nbsp;</strong> <br/>
 The number of hard interactions in the current event. Is 0 for elastic
 and diffractive events, and else at least 1, with more possible from
 multiparton interactions.
   
 
-<a name="method44"></a>
+<a name="method46"></a>
 <p/><strong>int Info::codeMPI(int i) &nbsp;</strong> <br/>
   
 <strong>double Info::pTMPI(int i) &nbsp;</strong> <br/>
@@ -449,10 +531,10 @@ subprocess, with <code>i</code> in the range from 0 to
 information already provided above.  
   
 
-<a name="method45"></a>
-<p/><strong>int Info::iAMPI(i) &nbsp;</strong> <br/>
+<a name="method47"></a>
+<p/><strong>int Info::iAMPI(int i) &nbsp;</strong> <br/>
   
-<strong>int Info::iBMPI(i) &nbsp;</strong> <br/>
+<strong>int Info::iBMPI(int i) &nbsp;</strong> <br/>
 are normally zero. However, if the <code>i</code>'th subprocess is
 a rescattering, i.e. either or both incoming partons come from the 
 outgoing state of previous scatterings, they give the position in the
@@ -461,8 +543,8 @@ event record of the outgoing-state parton that rescatters.
 the first or second beam, respectively.
   
 
-<a name="method46"></a>
-<p/><strong>double Info::eMPI(i) &nbsp;</strong> <br/>
+<a name="method48"></a>
+<p/><strong>double Info::eMPI(int i) &nbsp;</strong> <br/>
 The enhancement or depletion of the rate of the <code>i</code>'th 
 subprocess. Is primarily of interest for the 
 <code>MultipartonInteractions:bProfile = 4</code> option, where the 
@@ -473,18 +555,26 @@ partons. Note that <code>eMPI(0) = enhanceMPI()</code>.
 <h3>Cross sections</h3>
 
 Here are the currently available methods related to the event sample 
-as a whole. While continuously updated during the run, it is recommended
-only to study these properties at the end of the event generation, 
-when the full statistics is available.
+as a whole, for the default value <code>i = 0</code>, and otherwise for 
+the specific process code provided as argument. This is the number 
+obtained with <code>Info::code()</code>, while the further subdivision
+given by <code>Info::codeSub()</code> is not bookkept. While continuously 
+updated during the run, it is recommended only to study these properties 
+at the end of the event generation, when the full statistics is available.
+The individual process results are not available if 
+<?php $filepath = $_GET["filepath"];
+echo "<a href='ASecondHardProcess.php?filepath=".$filepath."' target='page'>";?>a second hard process</a> has been 
+chosen, but can be gleaned from the <code>pythia.stat()</code> output.
 
-<a name="method47"></a>
-<p/><strong>long Info::nTried() &nbsp;</strong> <br/>
+<a name="method49"></a>
+<p/><strong>long Info::nTried(int i = 0) &nbsp;</strong> <br/>
   
-<strong>long Info::nSelected() &nbsp;</strong> <br/>
+<strong>long Info::nSelected(int i = 0) &nbsp;</strong> <br/>
   
-<strong>long Info::nAccepted() &nbsp;</strong> <br/>
+<strong>long Info::nAccepted(int i = 0) &nbsp;</strong> <br/>
 the total number of tried phase-space points, selected hard processes
-and finally accepted events, summed over all allowed subprocesses.
+and finally accepted events, summed over all allowed processes
+(<code>i = 0</code>) or for the given process.
 The first number is only intended for a study of the phase-space selection
 efficiency. The last two numbers usually only disagree if the user introduces 
 some veto during the event-generation process; then the former is the number 
@@ -494,13 +584,14 @@ echo "<a href='ASecondHardProcess.php?filepath=".$filepath."' target='page'>";?>
 second hard process</a> there may also be a mismatch. 
   
 
-<a name="method48"></a>
-<p/><strong>double Info::sigmaGen() &nbsp;</strong> <br/>
+<a name="method50"></a>
+<p/><strong>double Info::sigmaGen(int i = 0) &nbsp;</strong> <br/>
   
-<strong>double Info::sigmaErr() &nbsp;</strong> <br/>
+<strong>double Info::sigmaErr(int i = 0) &nbsp;</strong> <br/>
 the estimated cross section and its estimated error,
-summed over all allowed subprocesses, in units of mb. The numbers refer to
-the accepted event sample above, i.e. after any user veto. 
+summed over all allowed processes (<code>i = 0</code>) or for the given
+process, in units of mb. The numbers refer to the accepted event sample 
+above, i.e. after any user veto. 
   
 
 <h3>Loop counters</h3>
@@ -512,7 +603,7 @@ This may be especially useful in the context of the
 <code><?php $filepath = $_GET["filepath"];
 echo "<a href='UserHooks.php?filepath=".$filepath."' target='page'>";?>User Hooks</a></code> facility.
 
-<a name="method49"></a>
+<a name="method51"></a>
 <p/><strong>int Info::getCounter(int i) &nbsp;</strong> <br/>
 the method that gives you access to the value of the various loop 
 counters.
@@ -616,7 +707,7 @@ that therefore are free to use, with the help of the two methods below.
   
   
 
-<a name="method50"></a>
+<a name="method52"></a>
 <p/><strong>void Info::setCounter(int i, int value = 0) &nbsp;</strong> <br/>
 set the above counters to a given value. Only to be used by you 
 for the unassigned counters 40 - 49.
@@ -627,7 +718,7 @@ normally the default value is what you want.
   
   
 
-<a name="method51"></a>
+<a name="method53"></a>
 <p/><strong>void Info::addCounter(int i, int value = 0) &nbsp;</strong> <br/>
 increase the above counters by a given amount. Only to be used by you 
 for the unassigned counters 40 - 49.
@@ -643,7 +734,7 @@ normally the default value is what you want.
 The following methods are mainly intended for internal use,
 e.g. for matrix-element matching.
 
-<a name="method52"></a>
+<a name="method54"></a>
 <p/><strong>void Info::hasHistory(bool hasHistoryIn) &nbsp;</strong> <br/>
   
 <strong>bool Info::hasHistory() &nbsp;</strong> <br/>
@@ -651,21 +742,47 @@ set/get knowledge whether the likely shower history of an event
 has been traced.
   
 
-<a name="method53"></a>
+<a name="method55"></a>
 <p/><strong>void Info::zNowISR(bool zNowIn) &nbsp;</strong> <br/>
   
 <strong>double Info::zNowISR() &nbsp;</strong> <br/>
 set/get value of <i>z</i> in latest ISR branching.
   
 
-<a name="method54"></a>
+<a name="method56"></a>
 <p/><strong>void Info::pT2NowISR(bool pT2NowIn) &nbsp;</strong> <br/>
   
 <strong>double Info::pT2NowISR() &nbsp;</strong> <br/>
 set/get value of <i>pT^2</i> in latest ISR branching.
   
 
+<h3>Header information</h3>
+
+A simple string key/value store, mainly intended for accessing
+information that is stored in the header block of Les Houches Event
+(LHE) files. In principle, any <code>LHAup</code> derived class can set
+this header information, which can then be read out later. Although the
+naming convention is arbitrary, in practice, it is dictated by the
+XML-like format of LHE files, see <?php $filepath = $_GET["filepath"];
+echo "<a href='LesHouchesAccord.php?filepath=".$filepath."' target='page'>";?>
+Les Houches Accord</a> for more details.
+
+<a name="method57"></a>
+<p/><strong>string Info::header(string key) &nbsp;</strong> <br/>
+return the header named <code>key</code>
+  
+
+<a name="method58"></a>
+<p/><strong>vector &lt;string&gt; Info::headerKeys() &nbsp;</strong> <br/>
+return a vector of all header key names
+  
+
+<a name="method59"></a>
+<p/><strong>void Info::setHeader(string key, string val) &nbsp;</strong> <br/>
+set the header named <code>key</code> with the contents of <code>val</code>
+  
+
 </body>
 </html>
 
-<!-- Copyright (C) 2012 Torbjorn Sjostrand -->
+<!-- Copyright (C) 2013 Torbjorn Sjostrand -->
