@@ -190,7 +190,7 @@ The question is whether the FSR should be allowed to occur at larger
 scales than the hard process it surrounds. This is process-dependent,
 as illustrated below for the the analogous 
 <code>SpaeShower::limitPTmax(...)</code> method, although the two
-kinds of radiation need not have to be modelled identically.
+kinds of radiation need not have to be modeled identically.
 The <code>TimeShower:pTmaxMatch</code> switch allows you to force the
 behaviour among three options, but you may replace by your own logic. 
 <br/>The internal PYTHIA implementation also allows intermediate options, 
@@ -234,6 +234,18 @@ below, it may well be that the existing code need not be replaced.
   
 
 <a name="method8"></a>
+<p/><strong>virtual int TimeShower::showerQED( int iBeg, int iEnd, Event& event, double pTmax) &nbsp;</strong> <br/>
+This is a further simplified version of the <code>shower</code>
+method above. Currently it only handles the emission of photons 
+in the decay of a hadron into a pair of leptons, either a charged
+lepton-antilepton or a lepton-neutrino pair. It is properly matched
+to the matrix element in the decay via a virtual photon or 
+<i>W^+-</i>, respectively. It is called as part of such decays
+if <code>ParticleDecays:allowPhotonRadiation = on</code>, which is
+not the default value.  
+  
+
+<a name="method9"></a>
 <p/><strong>double TimeShower::pTLastInShower() &nbsp;</strong> <br/>
 Can be used to return the <i>pT</i> evolution scale of the last
 branching in the cascade generated with the above 
@@ -242,7 +254,7 @@ branching in the cascade generated with the above
 were no branchings. Can be useful for matching studies. 
   
 
-<a name="method9"></a>
+<a name="method10"></a>
 <p/><strong>virtual void TimeShower::prepare( int iSys, Event& event) &nbsp;</strong> <br/>
 This method is called immediately after a new interaction (or the
 products of a resonance decay) has been added, and should then be used 
@@ -259,7 +271,7 @@ or are 0 for resonance decays unrelated to the beams, while the
 rest are not required to be in any particular order.
   
 
-<a name="method10"></a>
+<a name="method11"></a>
 <p/><strong>virtual void TimeShower::rescatterUpdate( int iSys, Event& event) &nbsp;</strong> <br/>
 This method is called immediately after rescattering in the description
 of multiparton interactions. Thus the information on one or several 
@@ -269,7 +281,7 @@ of new showers will want to touch the technicalities involved
 in obtaining a description of rescattering.
   
 
-<a name="method11"></a>
+<a name="method12"></a>
 <p/><strong>virtual void TimeShower::update( int iSys, Event& event) &nbsp;</strong> <br/>
 This method is called immediately after a spacelike branching in the 
 <code>iSys</code>'th subsystem. Thus the information for that system is 
@@ -279,7 +291,7 @@ free to throw away all information for the affected subsystem and call
 you may choose only to update the information that has changed.
   
 
-<a name="method12"></a>
+<a name="method13"></a>
 <p/><strong>virtual double TimeShower::pTnext( Event& event, double pTbegAll, double pTendAll) &nbsp;</strong> <br/>
 This is the main driver routine for the downwards evolution. A new 
 <i>pT</i> is to be selected based on the current information set up 
@@ -294,7 +306,7 @@ already been selected for MPI or ISR it makes no sense to look for
 a scale smaller than that from FSR, since it would not be able to 
 compete, so <code>pTendAll</code> is set correspondingly. As it happens, 
 FSR is tried before ISR and MPI in the interleaved evolution,
-but this is an implementational detail that could well change.  
+but this is an implementation detail that could well change.  
 <br/>Typically the implementation of this routine would be to set
 up a loop over all possible radiating objects (dipoles, dipole ends, ...),
 for each pick its possible branching scale and then pick the one 
@@ -303,7 +315,7 @@ actually be carried out, since MPI, ISR and FSR still have to be compared
 to assign the winner.
   
 
-<a name="method13"></a>
+<a name="method14"></a>
 <p/><strong>virtual bool TimeShower::branch( Event& event, bool isInterleaved = false) &nbsp;</strong> <br/>
 This method will be called once FSR has won the competition with 
 MPI and ISR to do the next branching. The candidate branching found 
@@ -323,7 +335,7 @@ More precisely, it separates calls to the <code>timesDecPtr</code>
 and the <code>timesPtr</code> instances.
   
 
-<a name="method14"></a>
+<a name="method15"></a>
 <p/><strong>virtual bool TimeShower::rescatterPropogateRecoil( Event& event, Vec4& pNew) &nbsp;</strong> <br/>
 This method is only called if rescattering is switched on in the 
 description of multiparton interactions. It then propagates a recoil
@@ -332,17 +344,17 @@ As for <code>rescatterUpdate</code> above, this is not likely to be
 of interest to most implementors of new showers.
   
 
-<a name="method15"></a>
+<a name="method16"></a>
 <p/><strong>int TimeShower::system() &nbsp;</strong> <br/>
 This method is not virtual. If a branching is constructed by the 
 previous routine this tiny method should be able to return the number 
-of the selected subsystem <code>iSysSel</code> where it occured, 
+of the selected subsystem <code>iSysSel</code> where it occurred, 
 so that the spacelike shower can be told which system to update, 
 if necessary. Therefore <code>iSysSel</code> must be set in 
 <code>branch</code> (or already in <code>pTnext</code>).  
   
 
-<a name="method16"></a>
+<a name="method17"></a>
 <p/><strong>virtual void TimeShower::list( ostream& os = cout) &nbsp;</strong> <br/>
 This method is not at all required. In the current implementation it 
 outputs a list of all the dipole ends, with information on the
@@ -361,23 +373,23 @@ description is simpler, since there are no special cases for resonance
 decays and non-interleaved evolution. Thus there is no correspondence 
 to the <code>TimeShower::shower(...)</code> routine.  
 
-<a name="method17"></a>
+<a name="method18"></a>
 <p/><strong>SpaceShower::SpaceShower() &nbsp;</strong> <br/>
 The constructor does not need to do anything.
   
 
-<a name="method18"></a>
+<a name="method19"></a>
 <p/><strong>virtual SpaceShower::~SpaceShower() &nbsp;</strong> <br/>
 Also the destructor does not need to do anything.
   
 
-<a name="method19"></a>
+<a name="method20"></a>
 <p/><strong>void SpaceShower::initPtr(Info* infoPtr, Settings* settingsPtr, ParticleData* particleDataPtr, Rndm* rndmPtr, PartonSystems* partonSystemsPtr, UserHooks* userHooksPtr) &nbsp;</strong> <br/>
 This method only imports pointers to standard facilities, 
 and is not virtual.
   
 
-<a name="method20"></a>
+<a name="method21"></a>
 <p/><strong>virtual void SpaceShower::init( BeamParticle* beamAPtrIn, BeamParticle* beamBPtrIn) &nbsp;</strong> <br/>
 You have to store your local copy of the pointers to these objects,
 since they have to be used during the generation, as explained above.
@@ -386,26 +398,26 @@ you plan to use, e.g. by reading in them from a user-accessible
 database like the <code>Settings</code> one.
   
 
-<a name="method21"></a>
+<a name="method22"></a>
 <p/><strong>virtual bool SpaceShower::limitPTmax( Event& event, double Q2Fac = 0.,  double Q2Ren = 0.) &nbsp;</strong> <br/>
 The question is whether the ISR should be allowed to occur at larger
 scales than the hard process it surrounds. This is process-dependent.
 For instance, if the hard process is <i>Z^0</i> production we know
 that ISR should be allowed to go right up to the kinematical limit.
 If it is a <i>2 -> 2</i> QCD process the ISR should not exceed
-the scale of the hard process, since if so one would doublecount.
+the scale of the hard process, since if so one would double-count.
 The <code>SpaceShower:pTmaxMatch</code> switch allows you to force the
 behaviour, or else to program your own logic. The current default
 implementation limits <i>pT</i> whenever the final state contains 
 a quark (except top), gluon or photon, since then the danger of 
-doublecounting is there. You may replace by your own logic, or leave as is. 
+double-counting is there. You may replace by your own logic, or leave as is. 
 <br/>The internal PYTHIA implementation also allows intermediate options, 
 where emissions can go up to the kinematical limit but be dampened above 
 the factorization or renormalization scale. Therefore the (square of the) 
 latter two are provided as optional input parameters.  
   
 
-<a name="method22"></a>
+<a name="method23"></a>
 <p/><strong>virtual double SpaceShower::enhancePTmax() &nbsp;</strong> <br/>
 When the above method limits <i>pT_max</i> to the scale of the process,
 it may still be convenient to vary the matching slightly for the hardest
@@ -414,7 +426,7 @@ base-class implementation returns the value of the
 <code>SpaceShower:pTmaxFudge</code> parameter.
   
 
-<a name="method23"></a>
+<a name="method24"></a>
 <p/><strong>virtual void SpaceShower::prepare( int iSys, Event& event, bool limitPTmax = true) &nbsp;</strong> <br/>
 This method is called immediately after a new interaction has been 
 added, and should then be used to prepare the subsystem of partons
@@ -429,10 +441,10 @@ the scales at which they were produced.
 <br/> The <code>limitPTmax</code> input agrees with the output of the
 previous method for the hardest process, and is always true for
 subsequent MPI, since there an unlimited <i>pT</i> for sure
-would lead to doublecounting.
+would lead to double-counting.
   
 
-<a name="method24"></a>
+<a name="method25"></a>
 <p/><strong>virtual void SpaceShower::update( int iSys, Event& event) &nbsp;</strong> <br/>
 This method is called immediately after a timelike branching in the 
 <code>iSys</code>'th subsystem. Thus the information for that system may 
@@ -441,7 +453,7 @@ this routine does not need to do anything, but that may be different
 in another implementation.
   
 
-<a name="method25"></a>
+<a name="method26"></a>
 <p/><strong>virtual double SpaceShower::pTnext( Event& event, double pTbegAll, double pTendAll, int nRadIn = -1) &nbsp;</strong> <br/>
 This is the main driver routine for the downwards evolution. A new 
 <i>pT</i> is to be selected based on the current information set up 
@@ -456,7 +468,7 @@ already been selected for MPI or ISR it makes no sense to look for
 a scale smaller than that from FSR, since it would not be able to 
 compete, so <code>pTendAll</code> is set correspondingly. As it happens, 
 FSR is tried before ISR and MPI in the interleaved evolution,
-but this is an implementational detail that could well change.  
+but this is an implementation detail that could well change.  
 <br/>Typically the implementation of this routine would be to set
 up a loop over all possible radiating objects (dipoles, dipole ends, ...),
 for each pick its possible branching scale and then pick the one 
@@ -468,7 +480,7 @@ ISR and FSR emissions already generated in the event, and so allows a
 special treatment for the very first emission, if desired.
   
 
-<a name="method26"></a>
+<a name="method27"></a>
 <p/><strong>virtual bool SpaceShower::branch( Event& event) &nbsp;</strong> <br/>
 This method will be called once FSR has won the competition with 
 MPI and ISR to do the next branching. The candidate branching found 
@@ -484,27 +496,27 @@ could be carried out. Also a complete restart of the parton-level
 description may be necessary, see <code>doRestart()</code> below.  
   
 
-<a name="method27"></a>
+<a name="method28"></a>
 <p/><strong>int SpaceShower::system() &nbsp;</strong> <br/>
 This method is not virtual. If a branching is constructed by the 
 previous routine this tiny method should be able to return the number 
-of the selected subsystem <code>iSysSel</code> where it occured, 
+of the selected subsystem <code>iSysSel</code> where it occurred, 
 so that the spacelike shower can be told which system to update, 
 if necessary. Therefore <code>iSysSel</code> must be set in 
 <code>branch</code> (or already in <code>pTnext</code>).  
   
 
-<a name="method28"></a>
+<a name="method29"></a>
 <p/><strong>bool SpaceShower::doRestart() &nbsp;</strong> <br/>
 This method is not virtual. If <code>branch(...)</code> above fails
 to construct a branching, and the conditions are such that the whole
 parton-level description should be restarted, then it should return
 true, else not. Currently only the rescattering description can give
-thi kind of failures, and so the internal <code>rescatterFail</code> 
+this kind of failures, and so the internal <code>rescatterFail</code> 
 boolean must be set true when this should happen, and else false.
   
 
-<a name="method29"></a>
+<a name="method30"></a>
 <p/><strong>virtual void SpaceShower::list( ostream& os = cout) &nbsp;</strong> <br/>
 This method is not at all required. In the current implementation it 
 outputs a list of all the dipole ends, with information on the
@@ -516,4 +528,4 @@ development/debug phase.
 </body>
 </html>
 
-<!-- Copyright (C) 2012 Torbjorn Sjostrand -->
+<!-- Copyright (C) 2013 Torbjorn Sjostrand -->
