@@ -169,7 +169,7 @@ are not yet included.
 <input type="radio" name="8" value="off" checked="checked"><strong>Off</strong>
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Pair production of a scalar quark together with a scalar antiquark by
-gluon annhilation via <i>s</i>-channel gluon exhange, <i>t</i>- and 
+gluon annihilation via <i>s</i>-channel gluon exchange, <i>t</i>- and 
 <i>u</i>-channel squark exchange, and the direct 4-point coupling. 
 The cross section expression follows [<a href="Bibliography.php" target="page">Boz07</a>]. 
 Validation of the FLV and CPV cases has not yet been completed.
@@ -249,7 +249,7 @@ Validation of the FLV and CPV cases has not yet been completed.
  &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
 Associated chargino-neutralino production by quark-antiquark
 annihilation. With four neutralino species, two chargino ones, and
-maintaining charge conjugate proceeses separate, this gives 16 
+maintaining charge conjugate processes separate, this gives 16 
 separate processes, codes 1221 - 1236. The cross section expressions 
 follow [<a href="Bibliography.php" target="page">Boz07</a>].
 Validation of the FLV and CPV cases has not yet been completed.
@@ -341,6 +341,20 @@ Still missing but to be included in a forthcoming update
 are: 3-body decays of charginos (via RPV), and 2-body decays of squarks and
 gauginos with Higgs as one of the decay products. 
 
+Some 3-body decays have been implemented with Matrix Element weighting.  
+In particular, those for a neutralino to a lighter neutralino and a fermion pair 
+can be enabled.
+
+<br/><br/><strong>SUSYResonance:3BodyMatrixElement</strong>  <input type="radio" name="21" value="on"><strong>On</strong>
+<input type="radio" name="21" value="off" checked="checked"><strong>Off</strong>
+ &nbsp;&nbsp;(<code>default = <strong>off</strong></code>)<br/>
+When "on", the spin-averaged, squared matrix element is used
+to sample the phase space for resonance decay.  Currently, only
+possible for a heavy neutralino decay to a light neutralino
+and a fermion-antifermion pair.
+  
+
+
 <input type="hidden" name="saved" value="1"/>
 
 <?php
@@ -456,6 +470,11 @@ if($_POST["20"] != "off")
 $data = "SUSY:qq2antisquark = ".$_POST["20"]."\n";
 fwrite($handle,$data);
 }
+if($_POST["21"] != "off")
+{
+$data = "SUSYResonance:3BodyMatrixElement = ".$_POST["21"]."\n";
+fwrite($handle,$data);
+}
 fclose($handle);
 }
 
@@ -463,5 +482,5 @@ fclose($handle);
 </body>
 </html>
 
-<!-- Copyright (C) 2012 Torbjorn Sjostrand -->
+<!-- Copyright (C) 2013 Torbjorn Sjostrand -->
 
