@@ -1,5 +1,5 @@
 // Analysis.cc is a part of the PYTHIA event generator.
-// Copyright (C) 2012 Torbjorn Sjostrand.
+// Copyright (C) 2013 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -766,7 +766,7 @@ bool CellJet::analyze(const Event& event, double eTjetMinIn,
   }
 
   // Smear true bin content by calorimeter resolution.
-  if (smear > 0 && rndmPtr > 0) 
+  if (smear > 0 && rndmPtr != 0) 
   for (int j = 0; j < int(cells.size()); ++j) {
     double eTeConv = (smear < 2) ? 1. : cosh( cells[j].etaCell );
     double eBef = cells[j].eTcell * eTeConv; 
@@ -956,7 +956,7 @@ bool SlowJet::setup(const Event& event) {
             ? log( max( TINY, pTemp.e() + pTemp.pz() ) / mTTemp )
             : log( mTTemp / max( TINY, pTemp.e() - pTemp.pz() ) );
     phiTemp = pTemp.phi();
-    clusters.push_back( SingleSlowJet(pTemp, pT2Temp, yTemp, phiTemp) );
+    clusters.push_back( SingleSlowJet(pTemp, pT2Temp, yTemp, phiTemp, i) );
   }
 
   // Resize arrays to store distances between clusters.
@@ -976,7 +976,9 @@ bool SlowJet::setup(const Event& event) {
     for (int j = 0; j < i; ++j) {
       dPhi = abs( clusters[i].phi - clusters[j].phi );
       if (dPhi > M_PI) dPhi = 2. * M_PI - dPhi;
-      dijTemp = (pow2( clusters[i].y - clusters[j].y) + dPhi*dPhi) / R2;
+      dijTemp = (useStandardR) 
+              ? (pow2( clusters[i].y - clusters[j].y) + dPhi*dPhi) / R2
+         : 2. * (cosh( clusters[i].y - clusters[j].y) - cos(dPhi)) / R2 ;
       if (isAnti)    dijTemp /= max(clusters[i].pT2, clusters[j].pT2); 
       else if (isKT) dijTemp *= min(clusters[i].pT2, clusters[j].pT2); 
       dij[i*(i-1)/2 + j] = dijTemp;
@@ -1020,7 +1022,7 @@ bool SlowJet::doStep() {
 
   // When distance between two clusters is smallest they are joined.
   else {
-     
+
     // Add iMin cluster to jMin.
     clusters[jMin].p  += clusters[iMin].p;
     clusters[jMin].pT2 = max( TINY*TINY, clusters[jMin].p.pT2());
@@ -1031,6 +1033,8 @@ bool SlowJet::doStep() {
       / max( TINY, clusters[jMin].p.e() - clusters[jMin].p.pz() ) );
     clusters[jMin].phi = clusters[jMin].p.phi();
     clusters[jMin].mult += clusters[iMin].mult;
+    clusters[jMin].idx.insert(clusters[iMin].idx.begin(),
+                              clusters[iMin].idx.end());
 
     // Update distances for and to new jMin.
     if (isAnti)    diB[jMin] = 1. / clusters[jMin].pT2;
@@ -1039,7 +1043,9 @@ bool SlowJet::doStep() {
     for (int i = 0; i < clSize; ++i) if (i != jMin && i != iMin) {
       dPhi = abs( clusters[i].phi - clusters[jMin].phi );
       if (dPhi > M_PI) dPhi = 2. * M_PI - dPhi;
-      dijTemp = (pow2( clusters[i].y - clusters[jMin].y) + dPhi*dPhi) / R2;
+      dijTemp = (useStandardR) 
+              ? (pow2( clusters[i].y - clusters[jMin].y) + dPhi*dPhi) / R2
+         : 2. * (cosh( clusters[i].y - clusters[jMin].y) - cos(dPhi)) / R2 ;
       if (isAnti)    dijTemp /= max(clusters[i].pT2, clusters[jMin].pT2); 
       else if (isKT) dijTemp *= min(clusters[i].pT2, clusters[jMin].pT2);
       if (i < jMin) dij[jMin*(jMin-1)/2 + i] = dijTemp;
@@ -1055,7 +1061,7 @@ bool SlowJet::doStep() {
       dij[iMin*(iMin-1)/2 + j] = dij[clLast*(clLast-1)/2 + j];
     for (int j = iMin + 1; j < clLast; ++j)
       dij[j*(j-1)/2 + iMin] = dij[clLast*(clLast-1)/2 + j];
-  }       
+  }
     
   // Shrink cluster list by one.
   clusters.pop_back();
