@@ -1,5 +1,5 @@
 // ParticleData.cc is a part of the PYTHIA event generator.
-// Copyright (C) 2012 Torbjorn Sjostrand.
+// Copyright (C) 2013 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -7,6 +7,7 @@
 // DecayChannel, ParticleDataEntry and ParticleData classes.
 
 #include "ParticleData.h"
+#include "ResonanceWidths.h"
 #include "StandardModel.h"
 #include "SusyResonanceWidths.h"
 
@@ -90,6 +91,10 @@ const int ParticleDataEntry::INVISIBLETABLE[50] = { 12, 14, 16, 18, 23, 25,
   4900211, 4900213, 4900991, 5000039, 5100039, 9900012, 9900014, 9900016, 
   9900023 };     
 
+// For some particles we know it is necessary to switch off width,
+// although they do have one, so do not warn.
+const int ParticleDataEntry::KNOWNNOWIDTH[3] = {10313, 10323, 10333}; 
+
 // Particles with a read-in tau0 (in mm/c) below this mayDecay by default.
 const double ParticleDataEntry::MAXTAU0FORDECAY = 1000.;
 
@@ -279,11 +284,16 @@ void ParticleDataEntry::initBWmass() {
 
   // Switch off Breit-Wigner if very close to threshold.
   if (mThr + NARROWMASS > m0Save) {
-    ostringstream osWarn;
-    osWarn << "for id = " << idSave;
-    particleDataPtr->infoPtr->errorMsg("Warning in ParticleDataEntry::"
-      "initBWmass: switching off width", osWarn.str(), true);
     modeBWnow = 0;
+    bool knownProblem = false;
+    for (int i = 0; i < 3; ++i) if (idSave == KNOWNNOWIDTH[i]) 
+      knownProblem = true;
+    if (!knownProblem) {
+      ostringstream osWarn;
+      osWarn << "for id = " << idSave;
+      particleDataPtr->infoPtr->errorMsg("Warning in ParticleDataEntry::"
+        "initBWmass: switching off width", osWarn.str(), true);
+    }
   }
 
 }
@@ -392,7 +402,7 @@ bool ParticleDataEntry::preparePick(int idSgn, double mHat, int idInFlav) {
   currentBRSum = 0.;
 
   // For resonances the widths are calculated dynamically.
-  if (resonancePtr != 0) {
+  if (isResonanceSave && resonancePtr != 0) {
     resonancePtr->widthStore(idSgn, mHat, idInFlav);
     for (int i = 0; i < int(channels.size()); ++i) 
       currentBRSum += channels[i].currentBR();
@@ -511,19 +521,6 @@ void ParticleDataEntry::setConstituentMass() {
 
 }
 
-//--------------------------------------------------------------------------
-
-// Convert string to lowercase for case-insensitive comparisons.
-
-string ParticleDataEntry::toLower(const string& nameConv) { 
-
-  string temp(nameConv);
-  for (int i = 0; i < int(temp.length()); ++i) 
-    temp[i] = std::tolower(temp[i]); 
-  return temp; 
-
-}
-
 //==========================================================================
 
 // ParticleData class.
@@ -634,6 +631,13 @@ void ParticleData::initWidths( vector<ResonanceWidths*> resonancePtrs) {
   resonancePtr = new ResonanceLeptoquark(42);
   setResonancePtr( 42, resonancePtr);
 
+  // 93 = Z0copy and 94 = W+-copy used to pick decay channels
+  // for W/Z production in parton showers.
+  resonancePtr = new ResonanceGmZ(93);
+  setResonancePtr( 93, resonancePtr);
+  resonancePtr = new ResonanceW(94);
+  setResonancePtr( 94, resonancePtr);
+
   // Supersymmetry
   //  - Squarks
   for(int i = 1; i < 7; i++){
@@ -857,7 +861,7 @@ bool ParticleData::readXML(string inFile, bool reset) {
       } else if (word1 == "<file") {
         string file = attributeValue(line, "name");
         if (file == "") {
-          infoPtr->errorMsg("Warning in ParticleData::readXML:"
+          infoPtr->errorMsg("Error in ParticleData::readXML:"
             " skip unrecognized file name", line);
         } else files.push_back(file);
       }
@@ -1135,8 +1139,9 @@ void ParticleData::listFF(string outFile) {
   // Check that valid particle.
   if ( (!isParticle(idTmp) && property  != "all" && property  != "new") 
   || idTmp <= 0) {
-    if (warn) os << "\n Warning: input particle not found in Particle"
-      << " Data Table; skip:\n   " << lineIn << "\n";
+    if (warn) os << "\n PYTHIA Error: input particle not found in Particle"
+      << " Data Table:\n   " << lineIn << "\n";
+    readingFailedSave = true;
     return false;
   }
 
@@ -1441,8 +1446,9 @@ void ParticleData::listFF(string outFile) {
   }
 
   // Return false if failed to recognize property.
-  if (warn) os << "\n Warning: input property not found in Particle"
-    << " Data Table; skip:\n   " << lineIn << "\n";
+  if (warn) os << "\n PYTHIA Error: input property not found in Particle"
+    << " Data Table:\n   " << lineIn << "\n";
+  readingFailedSave = true;
   return false;
 
 }
@@ -1994,7 +2000,9 @@ int ParticleData::nextId(int idIn) {
   // Find pointer to current particle and step up. Return 0 if impossible. 
   map<int, ParticleDataEntry>::const_iterator pdtIn = pdt.find(idIn);
   if (pdtIn == pdt.end()) return 0;
-  return (++pdtIn)->first;
+  ++pdtIn;
+  if (pdtIn == pdt.end()) return 0;
+  return pdtIn->first;
 
 }
 
@@ -2023,31 +2031,6 @@ double ParticleData::resOpenFrac(int id1In, int id2In, int id3In) {
 
 //--------------------------------------------------------------------------
 
-// Convert string to lowercase for case-insensitive comparisons.
-
-string ParticleData::toLower(const string& nameConv) { 
-
-  string temp(nameConv);
-  for (int i = 0; i < int(temp.length()); ++i) 
-    temp[i] = std::tolower(temp[i]); 
-  return temp; 
-
-}
-
-//--------------------------------------------------------------------------
-
-// Allow several alternative inputs for true/false.
-
-bool ParticleData::boolString(string tag) {
-
-  string tagLow = toLower(tag);
-  return ( tagLow == "true" || tagLow == "1" || tagLow == "on" 
-  || tagLow == "yes" || tagLow == "ok" ); 
-
-}  
-
-//--------------------------------------------------------------------------
-
 // Extract XML value string following XML attribute.
 
 string ParticleData::attributeValue(string line, string attribute) {
