@@ -1,5 +1,5 @@
 // ProcessLevel.cc is a part of the PYTHIA event generator.
-// Copyright (C) 2012 Torbjorn Sjostrand.
+// Copyright (C) 2013 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -32,7 +32,7 @@ ProcessLevel::~ProcessLevel() {
     delete containerPtrs[i];
 
   // Run through list of second hard processes and delete them.
-  for (int i =0; i < int(container2Ptrs.size()); ++i)
+  for (int i = 0; i < int(container2Ptrs.size()); ++i)
     delete container2Ptrs[i];
 
 } 
@@ -45,19 +45,19 @@ bool ProcessLevel::init( Info* infoPtrIn, Settings& settings,
   ParticleData* particleDataPtrIn, Rndm* rndmPtrIn, 
   BeamParticle* beamAPtrIn, BeamParticle* beamBPtrIn, 
   Couplings* couplingsPtrIn, SigmaTotal* sigmaTotPtrIn, bool doLHA, 
-  SusyLesHouches* slhaPtrIn, UserHooks* userHooksPtrIn, 
+  SLHAinterface* slhaInterfacePtrIn, UserHooks* userHooksPtrIn, 
   vector<SigmaProcess*>& sigmaPtrs, ostream& os) {
 
   // Store input pointers for future use. 
-  infoPtr         = infoPtrIn;
-  particleDataPtr = particleDataPtrIn;
-  rndmPtr         = rndmPtrIn;
-  beamAPtr        = beamAPtrIn;
-  beamBPtr        = beamBPtrIn;
-  couplingsPtr    = couplingsPtrIn;
-  sigmaTotPtr     = sigmaTotPtrIn;
-  userHooksPtr    = userHooksPtrIn;
-  slhaPtr         = slhaPtrIn;
+  infoPtr          = infoPtrIn;
+  particleDataPtr  = particleDataPtrIn;
+  rndmPtr          = rndmPtrIn;
+  beamAPtr         = beamAPtrIn;
+  beamBPtr         = beamBPtrIn;
+  couplingsPtr     = couplingsPtrIn;
+  sigmaTotPtr      = sigmaTotPtrIn;
+  userHooksPtr     = userHooksPtrIn;
+  slhaInterfacePtr = slhaInterfacePtrIn;
 
   // Send on some input pointers.
   resonanceDecays.init( infoPtr, particleDataPtr, rndmPtr);
@@ -139,6 +139,24 @@ bool ProcessLevel::init( Info* infoPtrIn, Settings& settings,
     return false;
   }
 
+  // Check whether pT-based weighting in 2 -> 2 is requested.
+  if (settings.flag("PhaseSpace:bias2Selection")) {
+    bool bias2Sel = false;
+    if (sigmaPtrs.size() == 0 && !doLHA && !doSecondHard) {
+      bias2Sel = true;
+      for (int i = 0; i < int(containerPtrs.size()); ++i) {
+        if (containerPtrs[i]->nFinal() != 2) bias2Sel = false;
+        int code = containerPtrs[i]->code();
+        if (code > 100 && code < 110) bias2Sel = false;
+      }
+    }
+    if (!bias2Sel) {
+      infoPtr->errorMsg("Error in ProcessLevel::init: "
+        "requested event weighting not possible"); 
+      return false;
+    }
+  } 
+
   // Check that SUSY couplings were indeed initialized where necessary.
   bool hasSUSY = false;
   for (int i = 0; i < int(containerPtrs.size()); ++i)
@@ -151,15 +169,15 @@ bool ProcessLevel::init( Info* infoPtrIn, Settings& settings,
     return false;
   }
 
-  // Initialize SLHA blocks SMINPUTS and MASS from PYTHIA SM parameter values.
-  initSLHA();
+  // Fill SLHA blocks SMINPUTS and MASS from PYTHIA SM parameter values.
+  slhaInterfacePtr->pythia2slha(particleDataPtr);
 
   // Initialize each process. 
   int numberOn = 0;
   for (int i = 0; i < int(containerPtrs.size()); ++i)
     if (containerPtrs[i]->init(true, infoPtr, settings, particleDataPtr, 
       rndmPtr, beamAPtr, beamBPtr, couplingsPtr, sigmaTotPtr,  
-      &resonanceDecays, slhaPtr, userHooksPtr)) ++numberOn;
+      &resonanceDecays, slhaInterfacePtr, userHooksPtr)) ++numberOn;
 
   // Sum maxima for Monte Carlo choice.
   sigmaMaxSum = 0.;
@@ -178,7 +196,7 @@ bool ProcessLevel::init( Info* infoPtrIn, Settings& settings,
     for (int i2 = 0; i2 < int(container2Ptrs.size()); ++i2)
       if (container2Ptrs[i2]->init(false, infoPtr, settings, particleDataPtr, 
         rndmPtr, beamAPtr, beamBPtr, couplingsPtr, sigmaTotPtr, 
-        &resonanceDecays, slhaPtr, userHooksPtr)) ++number2On;
+        &resonanceDecays, slhaInterfacePtr, userHooksPtr)) ++number2On;
     sigma2MaxSum = 0.;
     for (int i2 = 0; i2 < int(container2Ptrs.size()); ++i2)
       sigma2MaxSum += container2Ptrs[i2]->sigmaMax();
@@ -298,10 +316,6 @@ bool ProcessLevel::init( Info* infoPtrIn, Settings& settings,
   sumImpactFac  = 0.;
   sum2ImpactFac = 0.;
 
-  // Statistics for LHA events.
-  codeLHA.resize(0);
-  nEvtLHA.resize(0);
-
   // Done.
   return true;
 }
@@ -324,6 +338,26 @@ bool ProcessLevel::next( Event& process) {
 
 //--------------------------------------------------------------------------
 
+// Generate (= read in) LHA input of resonance decay only.
+  
+bool ProcessLevel::nextLHAdec( Event& process) {
+ 
+  // Read resonance decays from LHA interface.
+  infoPtr->setEndOfFile(false);
+  if (!lhaUpPtr->setEvent()) {
+    infoPtr->setEndOfFile(true);
+    return false;
+  }
+
+  // Store LHA output in standard event record format.
+  containerLHAdec.constructDecays( process); 
+
+  // Done.
+  return true;
+}
+
+//--------------------------------------------------------------------------
+
 // Accumulate and update statistics (after possible user veto).
   
 void ProcessLevel::accumulate() {
@@ -339,43 +373,34 @@ void ProcessLevel::accumulate() {
   double delta2Sum  = 0.;
   double sigSelSum  = 0.;
   double weightSum  = 0.;
+  int    codeNow;
+  long   nTryNow, nSelNow, nAccNow;
+  double sigmaNow, deltaNow, sigSelNow, weightNow;
   for (int i = 0; i < int(containerPtrs.size()); ++i) 
   if (containerPtrs[i]->sigmaMax() != 0.) {
-    nTrySum        += containerPtrs[i]->nTried();
-    nSelSum        += containerPtrs[i]->nSelected();
-    nAccSum        += containerPtrs[i]->nAccepted();
-    sigmaSum       += containerPtrs[i]->sigmaMC();
-    delta2Sum      += pow2(containerPtrs[i]->deltaMC()); 
-    sigSelSum      += containerPtrs[i]->sigmaSelMC();
-    weightSum      += containerPtrs[i]->weightSum();
-  }
-
-  // For Les Houches events find subprocess type and update counter.
-  if (infoPtr->isLHA()) {
-    int codeLHANow = infoPtr->codeSub();
-    int iFill = -1;
-    for (int i = 0; i < int(codeLHA.size()); ++i)
-      if (codeLHANow == codeLHA[i]) iFill = i;
-    if (iFill >= 0) ++nEvtLHA[iFill];
-
-    // Add new process when new code and then arrange in order. 
-    else {
-      codeLHA.push_back(codeLHANow);
-      nEvtLHA.push_back(1);
-      for (int i = int(codeLHA.size()) - 1; i > 0; --i) {
-        if (codeLHA[i] < codeLHA[i - 1]) { 
-          swap(codeLHA[i], codeLHA[i - 1]);
-          swap(nEvtLHA[i], nEvtLHA[i - 1]);
-	} 
-        else break;
-      }
-    }
+    codeNow         = containerPtrs[i]->code();
+    nTryNow         = containerPtrs[i]->nTried();
+    nSelNow         = containerPtrs[i]->nSelected();
+    nAccNow         = containerPtrs[i]->nAccepted();
+    sigmaNow        = containerPtrs[i]->sigmaMC();
+    deltaNow        = containerPtrs[i]->deltaMC(); 
+    sigSelNow       = containerPtrs[i]->sigmaSelMC();
+    weightNow       = containerPtrs[i]->weightSum();
+    nTrySum        += nTryNow;
+    nSelSum        += nSelNow;
+    nAccSum        += nAccNow;
+    sigmaSum       += sigmaNow;
+    delta2Sum      += pow2(deltaNow);
+    sigSelSum      += sigSelNow;
+    weightSum      += weightNow;
+    if (!doSecondHard) infoPtr->setSigma( codeNow, nTryNow, nSelNow, 
+      nAccNow, sigmaNow, deltaNow, weightNow); 
   }
 
   // Normally only one hard interaction. Then store info and done.
   if (!doSecondHard) {
     double deltaSum = sqrtpos(delta2Sum);
-    infoPtr->setSigma( nTrySum, nSelSum, nAccSum, sigmaSum, deltaSum, 
+    infoPtr->setSigma( 0, nTrySum, nSelSum, nAccSum, sigmaSum, deltaSum, 
       weightSum); 
     return;
   }
@@ -411,7 +436,7 @@ void ProcessLevel::accumulate() {
   double deltaComb  = sqrtpos(2. / nAccSum + impactErr2) * sigmaComb;
 
   // Store info and done.
-  infoPtr->setSigma( nTrySum, nSelSum, nAccSum, sigmaComb, deltaComb, 
+  infoPtr->setSigma( 0, nTrySum, nSelSum, nAccSum, sigmaComb, deltaComb, 
     weightSum); 
  
 }
@@ -476,10 +501,13 @@ void ProcessLevel::statistics(bool reset, ostream& os) {
 
     // Print subdivision by user code for Les Houches process.
     if (containerPtrs[i]->code() == 9999) 
-    for (int j = 0; j < int(codeLHA.size()); ++j)
+      for (int j = 0; j < containerPtrs[i]->codeLHASize(); ++j)
       os << " |    ... whereof user classification code " << setw(10) 
-         << codeLHA[j] << " |                        " << setw(10) 
-         << nEvtLHA[j] << " |                        | \n";
+         << containerPtrs[i]->subCodeLHA(j) << " | " 
+         << setw(11) << containerPtrs[i]->nTriedLHA(j) << " " << setw(10) 
+	 << containerPtrs[i]->nSelectedLHA(j) << " "
+         << setw(10) << containerPtrs[i]->nAcceptedLHA(j) 
+	 << " |                        | \n";
   }
 
   // Print summed process info.
@@ -511,58 +539,12 @@ void ProcessLevel::resetStatistics() {
     containerPtrs[i]->reset();
   if (doSecondHard)  
   for (int i2 = 0; i2 < int(container2Ptrs.size()); ++i2)
-      container2Ptrs[i2]->reset();
+    container2Ptrs[i2]->reset();
 
 }
 
 //--------------------------------------------------------------------------
 
-// Initialize SLHA blocks SMINPUTS and MASS from PYTHIA SM parameter values.
-
-void ProcessLevel::initSLHA() {
-
-  // Initialize block SMINPUTS.
-  string blockName = "sminputs";
-  double mZ = particleDataPtr->m0(23);
-  slhaPtr->set(blockName,1,1.0/couplingsPtr->alphaEM(pow2(mZ)));
-  slhaPtr->set(blockName,2,couplingsPtr->GF());
-  slhaPtr->set(blockName,3,couplingsPtr->alphaS(pow2(mZ)));
-  slhaPtr->set(blockName,4,mZ);
-  // b mass (should be running mass, here pole for time being)
-  slhaPtr->set(blockName,5,particleDataPtr->m0(5));
-  slhaPtr->set(blockName,6,particleDataPtr->m0(6));
-  slhaPtr->set(blockName,7,particleDataPtr->m0(15));
-  slhaPtr->set(blockName,8,particleDataPtr->m0(16));
-  slhaPtr->set(blockName,11,particleDataPtr->m0(11));
-  slhaPtr->set(blockName,12,particleDataPtr->m0(12));
-  slhaPtr->set(blockName,13,particleDataPtr->m0(13));
-  slhaPtr->set(blockName,14,particleDataPtr->m0(14));
-  // Force 3 lightest quarks massless 
-  slhaPtr->set(blockName,21,double(0.0));
-  slhaPtr->set(blockName,22,double(0.0));
-  slhaPtr->set(blockName,23,double(0.0));
-  // c mass (should be running mass, here pole for time being)
-  slhaPtr->set(blockName,24,particleDataPtr->m0(4));
-
-  // Initialize block MASS.
-  blockName = "mass";
-  int id = 1; 
-  int count = 0;
-  while (particleDataPtr->nextId(id) > id) {
-    slhaPtr->set(blockName,id,particleDataPtr->m0(id));
-    id = particleDataPtr->nextId(id);
-    ++count;
-    if (count > 10000) {
-      infoPtr->errorMsg("Error in ProcessLevel::initSLHA: "
-		      "encountered infinite loop when saving mass block");
-      break;
-    }
-  }
-  
-}
-
-//--------------------------------------------------------------------------
-
 // Generate the next event with one interaction.
   
 bool ProcessLevel::nextOne( Event& process) {
@@ -603,6 +585,7 @@ bool ProcessLevel::nextOne( Event& process) {
     }
 
     // Construct kinematics of acceptable process.
+    containerPtrs[iContainer]->constructState();
     if ( !containerPtrs[iContainer]->constructProcess( process) )
       physical = false;
 
@@ -689,6 +672,10 @@ bool ProcessLevel::nextTwo( Event& process) {
           sigma2MaxSum += container2Ptrs[i2]->sigmaMax();
       }
 
+      // Pick incoming flavours (etc), needed for PDF reweighting.
+      containerPtrs[iContainer]->constructState();
+      container2Ptrs[i2Container]->constructState();
+
       // Check whether common set of x values is kinematically possible.
       double xA1      = containerPtrs[iContainer]->x1();
       double xB1      = containerPtrs[iContainer]->x2();
@@ -866,7 +853,8 @@ void ProcessLevel::findJunctions( Event& junEvent) {
     
     // Ignore colorless particles and stages before hard-scattering 
     // final state. 
-    if (abs(junEvent[i].status()) <= 21 || junEvent[i].colType() == 0) continue;
+    if (abs(junEvent[i].status()) <= 21 || junEvent[i].colType() == 0) 
+      continue;
     vector<int> motherList   = junEvent.motherList(i);
     int iMot1 = motherList[0];
     vector<int> sisterList = junEvent.daughterList(iMot1);        
@@ -897,7 +885,8 @@ void ProcessLevel::findJunctions( Event& junEvent) {
 	if (colVertex.find(acol) == colVertex.end()) acolVertex[acol] = iMot;
 	else colVertex.erase(acol);
       } else if (acol < 0) {
-	if (acolVertex.find(-acol) == acolVertex.end()) colVertex[-acol] = iMot;
+	if (acolVertex.find(-acol) == acolVertex.end()) 
+             colVertex[-acol] = iMot;
 	else acolVertex.erase(-acol);
       }
     }
@@ -924,7 +913,8 @@ void ProcessLevel::findJunctions( Event& junEvent) {
 	if (colVertex.find(acol) == colVertex.end()) acolVertex[acol] = iDau;
 	else colVertex.erase(acol);
       } else if (acol < 0) {
-	if (acolVertex.find(-acol) == acolVertex.end()) colVertex[-acol] = iDau;
+	if (acolVertex.find(-acol) == acolVertex.end()) 
+             colVertex[-acol] = iDau;
 	else acolVertex.erase(-acol);
       }
     
