@@ -1,5 +1,5 @@
 // SigmaTotal.cc is a part of the PYTHIA event generator.
-// Copyright (C) 2012 Torbjorn Sjostrand.
+// Copyright (C) 2013 Torbjorn Sjostrand.
 // PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
 // Please respect the MCnet Guidelines, see GUIDELINES for details.
 
@@ -25,7 +25,8 @@ namespace Pythia8 {
 // =  5 : phi + p;   =  6 : J/psi + p;
 // =  7 : rho + rho; =  8 : rho + phi;   =  9 : rho + J/psi;
 // = 10 : phi + phi; = 11 : phi + J/psi; = 12 : J/psi + J/psi.  
-// = 13 : Pom + p (preliminary). 
+// = 13 : Pom + p (preliminary).
+// For now a neutron is treated like a proton.  
 
 //--------------------------------------------------------------------------
  
@@ -125,6 +126,10 @@ void SigmaTotal::init(Info* infoPtrIn, Settings& settings,
   infoPtr         = infoPtrIn;
   particleDataPtr = particleDataPtrIn;
 
+  // Normalization of central diffractive cross section.
+  zeroAXB    = settings.flag("SigmaTotal:zeroAXB");
+  sigAXB2TeV = settings.parm("SigmaTotal:sigmaAXB2TeV");
+
   // User-set values for cross sections.  
   setTotal   = settings.flag("SigmaTotal:setOwn");
   sigTotOwn  = settings.parm("SigmaTotal:sigmaTot");
@@ -139,6 +144,7 @@ void SigmaTotal::init(Info* infoPtrIn, Settings& settings,
   maxXBOwn   = settings.parm("SigmaDiffractive:maxXB");
   maxAXOwn   = settings.parm("SigmaDiffractive:maxAX");
   maxXXOwn   = settings.parm("SigmaDiffractive:maxXX");
+  maxAXBOwn  = settings.parm("SigmaDiffractive:maxAXB");
 
   // User-set values for handling of elastic sacattering. 
   setElastic = settings.flag("SigmaElastic:setOwn");
@@ -154,7 +160,7 @@ void SigmaTotal::init(Info* infoPtrIn, Settings& settings,
   pPomP      = settings.parm("Diffraction:mPowPomP");
   
   // Parameters for MBR model.
- PomFlux      = settings.mode("Diffraction:PomFlux"); 
+  PomFlux     = settings.mode("Diffraction:PomFlux"); 
   MBReps      = settings.parm("Diffraction:MBRepsilon");
   MBRalpha    = settings.parm("Diffraction:MBRalpha");
   MBRbeta0    = settings.parm("Diffraction:MBRbeta0");
@@ -314,11 +320,22 @@ bool SigmaTotal::calc( int idA, int idB, double eCM) {
     / max( 0.1, alP2 * log( s * s0 / (sRMavgAX * sRMavgXB) ) + BcorrXX);
   sigXX  = CONVERTDD * X[iProc] * max( 0., sum1 + sum2 + sum3 + sum4);
 
+  // Central diffractive scattering A + B -> A + X + B, only p and pbar.
+  mMinAXBsave = 1.;
+  if ( (idAbsA == 2212 || idAbsA == 2112)
+    && (idAbsB == 2212 || idAbsB == 2112) && !zeroAXB) {
+    double sMinAXB = pow2(mMinAXBsave);
+    double sRefAXB = pow2(2000.);
+    sigAXB = sigAXB2TeV * pow( log(0.06 * s / sMinAXB), 1.5 )
+           / pow( log(0.06 * sRefAXB / sMinAXB), 1.5 );
+  }
+
   // Option with user-requested damping of diffractive cross sections.
   if (doDampen) {
-    sigXB = sigXB * maxXBOwn / (sigXB + maxXBOwn);
-    sigAX = sigAX * maxAXOwn / (sigAX + maxAXOwn);
-    sigXX = sigXX * maxXXOwn / (sigXX + maxXXOwn);
+    sigXB  = sigXB  * maxXBOwn  / (sigXB  + maxXBOwn);
+    sigAX  = sigAX  * maxAXOwn  / (sigAX  + maxAXOwn);
+    sigXX  = sigXX  * maxXXOwn  / (sigXX  + maxXXOwn);
+    sigAXB = sigAXB * maxAXBOwn / (sigAXB + maxAXBOwn);
   }
   
   // Calculate cross sections in MBR model.
@@ -363,7 +380,7 @@ bool SigmaTotal::calc( int idA, int idB, double eCM) {
 
 }
 
-//==========================================================================
+//--------------------------------------------------------------------------
 
 // Calculate parameters in the MBR model.
 
@@ -502,9 +519,9 @@ bool SigmaTotal::calcMBRxsecs( int idA, int idB, double eCM) {
       f2         = exp(2. * eps * dy2) * ( (a1 / (b1 + 2. * alph * dy2))
                  + (a2 / (b2 + 2. * alph * dy2)) );
       f1        *= 0.5 * (1. + erf( (dy1 - 0.5 * dyminCD)
-                 / (dyminSigCD / sqrt(2))) );
+                 / (dyminSigCD / sqrt(2.))) );
       f2        *= 0.5 * (1. + erf( (dy2 - 0.5 *dyminCD)
-                 / (dyminSigCD / sqrt(2))) );
+                 / (dyminSigCD / sqrt(2.))) );
       f         += f1 * f2 * step2;      
     }
     fluxdpe     += step * c1 * f;    
@@ -529,9 +546,9 @@ bool SigmaTotal::calcMBRxsecs( int idA, int idB, double eCM) {
       f2         = exp(eps * dy2) * ( (a1 / (b1 + 2. * alph * dy2))
                  + (a2 / (b2 + 2. * alph * dy2)) );
       f1        *= 0.5 * (1. + erf( (dy1 - 0.5 * dyminCD) 
-                 / (dyminSigCD / sqrt(2))) );
+                 / (dyminSigCD / sqrt(2.))) );
       f2        *= 0.5 * (1. + erf( (dy2 - 0.5 * dyminCD)
-                 /(dyminSigCD / sqrt(2))) );
+                 /(dyminSigCD / sqrt(2.))) );
       f         += f1 * f2 * step2;      
     }
     sigdpe      += step * c1 * f;
